Info about QnAS:

To install: Go to pypi and find QnAS, 
there you can find the install command!

MIT License: Free to use!

QnAS is an open source program to 
simulate noisy quantum algorithms!

To see source code, go to: https://github.com/isakwi/Kandidatarbete/tree/main/qnas




To make package, follow these:
https://packaging.python.org/en/latest/tutorials/packaging-projects/
Important: name root folder and package folder same: so that we download QnAS and import QnAS,
it was a little confusing with my test package.

